gtrace.optics package
=====================

Submodules
----------

gtrace.optics.cavity module
---------------------------

.. automodule:: gtrace.optics.cavity
   :members:
   :undoc-members:
   :show-inheritance:

gtrace.optics.consts module
---------------------------

.. automodule:: gtrace.optics.consts
   :members:
   :undoc-members:
   :show-inheritance:

gtrace.optics.gaussian module
-----------------------------

.. automodule:: gtrace.optics.gaussian
   :members:
   :undoc-members:
   :show-inheritance:

gtrace.optics.geometric module
------------------------------

.. automodule:: gtrace.optics.geometric
   :members:
   :undoc-members:
   :show-inheritance:

gtrace.optics.unit module
-------------------------

.. automodule:: gtrace.optics.unit
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: gtrace.optics
   :members:
   :undoc-members:
   :show-inheritance:
